/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.servlet;

import org.wso2.registry.Resource;
import org.wso2.registry.RegistryException;
import org.wso2.registry.Registry;
import org.wso2.registry.RegistryConstants;
import org.wso2.registry.jdbc.realm.RegistryRealm;
import org.wso2.registry.secure.SecureRegistry;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.ServletContext;

public class ResourceHandlerUtil {

    public static Resource getResource(HttpServletRequest request, String path)
            throws RegistryException {

        SecureRegistry secureRegistry = getUserRegistry(request);

        String resourcePath = path;
        if (path.indexOf("?") > 0) {
            resourcePath = path.substring(0, path.indexOf("?"));
        }

        if (secureRegistry.resourceExists(resourcePath)) {
            return secureRegistry.get(path);
        } else {
            return null;
        }
    }

    public static SecureRegistry getUserRegistry(HttpServletRequest request)
            throws RegistryException {

        SecureRegistry userRegistry =
                (SecureRegistry) request.getSession().getAttribute(RegistryConstants.USER_REGISTRY);

        if (userRegistry == null) {

            // user is not logged in. create a annoymous userRegistry for the user.

            ServletContext context =
                    request.getSession().getServletContext();

            Registry jdbcRegistry =
                    (Registry) context.getAttribute(RegistryConstants.REGISTRY);


            RegistryRealm realm = (RegistryRealm) request.getSession().getServletContext().
                    getAttribute(RegistryConstants.REGISTRY_REALM);

            SecureRegistry secureRegistry = new SecureRegistry(
                    RegistryConstants.ANONYMOUS_USER, RegistryConstants.ANONYMOUS_PASSWORD, jdbcRegistry, realm);

            request.getSession().setAttribute(RegistryConstants.USER_REGISTRY, secureRegistry);

            userRegistry = secureRegistry;
        }

        return userRegistry;
    }
}
